@@ -36,8 +36,9 @@ from sqlite3 import connect as sqlite3_connect
 from pathlib import Path
 from contextlib import suppress
 
-#old_stderr = sys.stderr
-#sys.stderr = open(devnull, 'w')
+old_stderr = sys.stderr
+sys.stderr = open(devnull, 'w')
+
 
 def check_privileges():
     with suppress(Exception):
